# This Source Code Form is subject to the terms of the Mozilla Public
# License, v. 2.0. If a copy of the MPL was not distributed with this
# file, you can obtain one at http://mozilla.org/MPL/2.0/.
from __future__ import absolute_import
import logging

from dockerflow.flask import Dockerflow
from redash import migrate, redis_connection
from redash.models import db

logger = logging.getLogger(__name__)


def dockerflow(app):
    logger.info('Loading Redash Extension for Dockerflow')
    dockerflow = Dockerflow(app, db=db, migrate=migrate, redis=redis_connection)
    logger.info('Loaded Redash Extension for Dockerflow')
    return dockerflow



from setuptools import setup, find_packages

setup(
    name='redash-stmo',
    use_scm_version={
        'version_scheme': 'post-release',
        'local_scheme': 'dirty-tag'
    },
    setup_requires=['setuptools_scm'],
    install_requires=[
        'dockerflow>=2018.2.0',
        'requests',
    ],
    packages=find_packages(where='src'),
    package_dir={'': 'src'},
    description="Extensions to Redash by Mozilla",
    author='Mozilla Foundation',
    author_email='dev-webdev@lists.mozilla.org',
    url='https://github.com/mozilla/redash-stmo',
    license='MPL 2.0',
    entry_points={
        'redash.extensions': [
            'dockerflow = redash_stmo.dockerflow:dockerflow',
        ],
    },
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Environment :: Web Environment :: Mozilla',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: Mozilla Public License 2.0 (MPL 2.0)',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Topic :: Internet :: WWW/HTTP',
    ],
    zip_safe=False,
)
